@@ -734,6 +734,57 @@ Math/pow overflows to Infinity."
                  (+ (* q d) r)
                  (unchecked-add (unchecked-multiply q d) r))))))
 
+(deftest unchecked-inc-overflow
+  (testing "max value overflows to min value"
+    (is (= Long/MIN_VALUE (unchecked-inc Long/MAX_VALUE)))
+    (is (= Long/MIN_VALUE (unchecked-inc (Long/valueOf Long/MAX_VALUE))))))
+
+(deftest unchecked-dec-overflow
+  (testing "min value overflows to max value"
+    (is (= Long/MAX_VALUE (unchecked-dec Long/MIN_VALUE)))
+    (is (= Long/MAX_VALUE (unchecked-dec (Long/valueOf Long/MIN_VALUE))))))
+
+(deftest unchecked-negate-overflow
+  (testing "negating min value overflows to min value itself"
+    (is (= Long/MIN_VALUE (unchecked-negate Long/MIN_VALUE)))
+    (is (= Long/MIN_VALUE (unchecked-negate (Long/valueOf Long/MIN_VALUE))))))
+
+(deftest unchecked-add-overflow
+  (testing "max value overflows to min value"
+    (is (= Long/MIN_VALUE (unchecked-add Long/MAX_VALUE 1)))
+    (is (= Long/MIN_VALUE (unchecked-add Long/MAX_VALUE (Long/valueOf 1))))
+    (is (= Long/MIN_VALUE (unchecked-add (Long/valueOf Long/MAX_VALUE) 1)))
+    (is (= Long/MIN_VALUE (unchecked-add (Long/valueOf Long/MAX_VALUE) (Long/valueOf 1)))))
+  (testing "adding min value to min value results in zero"
+    (is (= 0 (unchecked-add Long/MIN_VALUE Long/MIN_VALUE)))
+    (is (= 0 (unchecked-add Long/MIN_VALUE (Long/valueOf Long/MIN_VALUE))))
+    (is (= 0 (unchecked-add (Long/valueOf Long/MIN_VALUE) Long/MIN_VALUE)))
+    (is (= 0 (unchecked-add (Long/valueOf Long/MIN_VALUE) (Long/valueOf Long/MIN_VALUE))))))
+
+(deftest unchecked-subtract-overflow
+  (testing "min value overflows to max-value"
+    (is (= Long/MAX_VALUE (unchecked-subtract Long/MIN_VALUE 1)))
+    (is (= Long/MAX_VALUE (unchecked-subtract Long/MIN_VALUE (Long/valueOf 1))))
+    (is (= Long/MAX_VALUE (unchecked-subtract (Long/valueOf Long/MIN_VALUE) 1)))
+    (is (= Long/MAX_VALUE (unchecked-subtract (Long/valueOf Long/MIN_VALUE) (Long/valueOf 1)))))
+  (testing "negating min value overflows to min value itself"
+    (is (= Long/MIN_VALUE (unchecked-subtract 0 Long/MIN_VALUE)))
+    (is (= Long/MIN_VALUE (unchecked-subtract 0 (Long/valueOf Long/MIN_VALUE))))
+    (is (= Long/MIN_VALUE (unchecked-subtract (Long/valueOf 0) Long/MIN_VALUE)))
+    (is (= Long/MIN_VALUE (unchecked-subtract (Long/valueOf 0) (Long/valueOf Long/MIN_VALUE))))))
+
+(deftest unchecked-multiply-overflow
+  (testing "two times max value results in -2"
+    (is (= -2 (unchecked-multiply Long/MAX_VALUE 2)))
+    (is (= -2 (unchecked-multiply Long/MAX_VALUE (Long/valueOf 2))))
+    (is (= -2 (unchecked-multiply (Long/valueOf Long/MAX_VALUE) 2)))
+    (is (= -2 (unchecked-multiply (Long/valueOf Long/MAX_VALUE) (Long/valueOf 2)))))
+  (testing "two times min value results in 0"
+    (is (= 0 (unchecked-multiply Long/MIN_VALUE 2)))
+    (is (= 0 (unchecked-multiply Long/MIN_VALUE (Long/valueOf 2))))
+    (is (= 0 (unchecked-multiply (Long/valueOf Long/MIN_VALUE) 2)))
+    (is (= 0 (unchecked-multiply (Long/valueOf Long/MIN_VALUE) (Long/valueOf 2))))))
+
 (defmacro check-warn-on-box [warn? form]
   `(do (binding [*unchecked-math* :warn-on-boxed]
                 (is (= ~warn?
